@@ -13,7 +13,8 @@
 #' @seealso plot_tb_burden plot_tb_burden_overview get_tb_burden search_data_dict
 #' @return A plot of TB Incidence Rates by Country
 #' @export
-#' @import ggplot2
+#' @importFrom ggplot2 ggplot aes geom_polygon coord_equal theme labs guides guide_legend facet_wrap
+#' @importFrom rlang .data
 #' @importFrom viridis scale_fill_viridis
 #' @importFrom ggthemes theme_map
 #' @import magrittr
@@ -63,6 +64,8 @@ map_tb_burden <- function(df = NULL, dict = NULL,
                            viridis_direction = -1,
                            viridis_end = 0.9,
                            verbose = TRUE, ...) {
+  
+  long <- NULL; lat <- NULL; Year <- NULL; 
   if (!is.null(facet) && facet %in% "year") {
     facet <- "Year"
   }
@@ -126,13 +129,13 @@ map_tb_burden <- function(df = NULL, dict = NULL,
   
   ## Check if variable is discrete or continous
   plot <- ggplot(df_prep$df, 
-                 aes_string(x = "long", 
-                            y = "lat", 
-                            text = "country",
-                            fill = metric,
-                            key = "country",
-                            frame = "Year")) +
-    geom_polygon(aes_string(group = "group"),
+                 aes(x = long, 
+                     y = lat, 
+                     text = country,
+                     fill = .data[[metric]],
+                     key = country,
+                     frame = Year)) +
+    geom_polygon(aes(group = group),
                  color = "black", size = 0.3, na.rm = TRUE) +
     coord_equal() +
     ggthemes::theme_map() +
